Exception: SynonymScrapper::WordFormatError
- Defined in:
- lib/synonym_scrapper.rb
Overview
Exception thrown when the word is not a string.
Instance Method Summary collapse
-
#initialize(word = "") ⇒ WordFormatError
constructor
A new instance of WordFormatError.
Constructor Details
#initialize(word = "") ⇒ WordFormatError
Returns a new instance of WordFormatError.
28 29 30 31 |
# File 'lib/synonym_scrapper.rb', line 28 def initialize(word = "") msg = "The word #{word} is not a string, it must be a string." super msg end |